@@ -1,25 +1,26 @@
 from __future__ import annotations
 
 import json
+import sys
 from functools import partial
 from typing import Any, List, Optional
 
 from meilisearch.errors import MeiliSearchApiError
-from rich.console import Console
 from rich.traceback import install
 from typer import Argument, Option, Typer
 
-from meilisearch_cli._config import MASTER_KEY_HELP_MESSAGE, URL_HELP_MESSAGE, WAIT_MESSAGE
+from meilisearch_cli._config import MASTER_KEY_OPTION, RAW_OPTION, URL_OPTION, WAIT_OPTION, console
 from meilisearch_cli._helpers import (
+    check_index_status,
     create_client,
     create_panel,
-    handle_index_meilisearch_api_error,
+    handle_meilisearch_api_error,
     print_json_parse_error_message,
+    print_panel_or_raw,
     process_request,
 )
 
-install(show_locals=True)
-console = Console()
+install()
 app = Typer()
 
 
@@ -27,10 +28,9 @@ app = Typer()
 def create(
     index: str = Argument(..., help="The name of the index to create"),
     primary_key: Optional[str] = Option(None, help="The primary key of the index"),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Create an index."""
 
@@ -42,23 +42,23 @@ def create(
             else:
                 response = client.create_index(index)
 
-        index_dict = response.__dict__
+            client.wait_for_task(response["uid"])
+            check_index_status(client.config, index, response["uid"])
+
+        client_index = client.get_index(index)
+        index_dict = client_index.__dict__
         del index_dict["config"]
         del index_dict["http"]
-        panel = create_panel(index_dict, title="Index")
-
-        console.print(panel)
+        print_panel_or_raw(raw, index_dict, "Index")
     except MeiliSearchApiError as e:
-        handle_index_meilisearch_api_error(e, index)
+        handle_meilisearch_api_error(e, index)
 
 
 @app.command()
 def delete(
     index: str = Argument(..., help="The name of the index to delete"),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
 ) -> None:
     """Delete an index."""
 
@@ -66,8 +66,9 @@ def delete(
     try:
         with console.status("Deleting the index..."):
             response = client.index(index).delete()
+            client.wait_for_task(response["uid"])
+            check_index_status(client.config, index, response["uid"])
 
-        response.raise_for_status()
         console.print(
             create_panel(
                 f"Index {index} successfully deleted",
@@ -75,16 +76,15 @@ def delete(
             )
         )
     except MeiliSearchApiError as e:
-        handle_index_meilisearch_api_error(e, index)
+        handle_meilisearch_api_error(e, index)
 
 
 @app.command()
 def get(
     index: str = Argument(..., help="The name of the index to retrieve"),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Gets a single index."""
 
@@ -92,37 +92,30 @@ def get(
     try:
         with console.status("Getting index..."):
             returned_index = client.get_raw_index(index)
-            panel = create_panel(returned_index, title="Index")
-
-        console.print(panel)
+            print_panel_or_raw(raw, returned_index, "Index")
     except MeiliSearchApiError as e:
-        handle_index_meilisearch_api_error(e, index)
+        handle_meilisearch_api_error(e, index)
 
 
 @app.command()
 def get_all(
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Get all indexes."""
 
     client = create_client(url, master_key)
     with console.status("Getting indexes..."):
         indexes = client.get_raw_indexes()
-        panel = create_panel(indexes, title="All Indexes")
-
-    console.print(panel)
+        print_panel_or_raw(raw, indexes, "All Indexes")
 
 
 @app.command()
 def get_primary_key(
     index: str = Argument(..., help="The name of the index from which to retrieve the primary key"),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
 ) -> None:
     """Get the primary key of an index."""
 
@@ -131,19 +124,17 @@ def get_primary_key(
         with console.status("Getting primary key..."):
             primary_key = client.index(index).get_primary_key()
             panel = create_panel(primary_key, title="Primary Key")
-
-        console.print(panel)
+            console.print(panel)
     except MeiliSearchApiError as e:
-        handle_index_meilisearch_api_error(e, index)
+        handle_meilisearch_api_error(e, index)
 
 
 @app.command()
 def get_stats(
     index: str = Argument(..., help="The name of the index from which to retrieve the stats"),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Get the stats of an index."""
 
@@ -151,43 +142,37 @@ def get_stats(
     try:
         with console.status("Getting stats..."):
             settings = client.index(index).get_stats()
-            panel = create_panel(settings, title="Stats")
-
-        console.print(panel)
+            print_panel_or_raw(raw, settings, "Stats")
     except MeiliSearchApiError as e:
-        handle_index_meilisearch_api_error(e, index)
+        handle_meilisearch_api_error(e, index)
 
 
 @app.command()
-def get_all_update_status(
+def get_tasks(
     index: str = Argument(
         ..., help="The name of the index from which to retrieve the update status"
     ),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Get all update statuses of an index."""
 
     client = create_client(url, master_key)
     try:
         with console.status("Getting update status..."):
-            status = client.index(index).get_all_update_status()
-            panel = create_panel(status, title="Update Status")
-
-        console.print(panel)
+            status = client.index(index).get_tasks()
+            print_panel_or_raw(raw, status, "Update Status")
     except MeiliSearchApiError as e:
-        handle_index_meilisearch_api_error(e, index)
+        handle_meilisearch_api_error(e, index)
 
 
 @app.command()
 def get_settings(
     index: str = Argument(..., help="The name of the index from which to retrieve the settings"),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Get the settings of an index."""
 
@@ -195,35 +180,30 @@ def get_settings(
     try:
         with console.status("Getting settings..."):
             settings = client.index(index).get_settings()
-            panel = create_panel(settings, title="Settings")
-
-        console.print(panel)
+            print_panel_or_raw(raw, settings, "Settings")
     except MeiliSearchApiError as e:
-        handle_index_meilisearch_api_error(e, index)
+        handle_meilisearch_api_error(e, index)
 
 
 @app.command()
-def get_update_status(
+def get_task(
     index: str = Argument(
         ..., help="The name of the index from which to retrieve the update status"
     ),
     update_id: int = Argument(..., help="The update ID for the update status"),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Get the update status of an index."""
 
     client = create_client(url, master_key)
     try:
         with console.status("Getting update status..."):
-            status = client.index(index).get_update_status(update_id)
-            panel = create_panel(status, title="Update Status")
-
-        console.print(panel)
+            status = client.index(index).get_task(update_id)
+            print_panel_or_raw(raw, status, "Update Status")
     except MeiliSearchApiError as e:
-        handle_index_meilisearch_api_error(e, index)
+        handle_meilisearch_api_error(e, index)
 
 
 @app.command()
@@ -231,11 +211,10 @@ def reset_displayed_attributes(
     index: str = Argument(
         ..., help="The name of the index for which to reset the displayed attributes"
     ),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
-    wait: bool = Option(False, "--wait", "-w", help=WAIT_MESSAGE),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    wait: bool = WAIT_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Reset displayed attributes of an index."""
 
@@ -248,9 +227,10 @@ def reset_displayed_attributes(
                 client_index.get_displayed_attributes,
                 wait,
                 "Reset Displayed Attributes",
+                raw,
             )
     except MeiliSearchApiError as e:
-        handle_index_meilisearch_api_error(e, index)
+        handle_meilisearch_api_error(e, index)
 
 
 @app.command()
@@ -258,11 +238,10 @@ def reset_distinct_attribute(
     index: str = Argument(
         ..., help="The name of the index for which to reset the distinct attribute"
     ),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
-    wait: bool = Option(False, "--wait", "-w", help=WAIT_MESSAGE),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    wait: bool = WAIT_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Reset distinct attribute of an index."""
 
@@ -275,9 +254,10 @@ def reset_distinct_attribute(
                 client_index.get_distinct_attribute,
                 wait,
                 "Reset Distinct Attribute",
+                raw,
             )
     except MeiliSearchApiError as e:
-        handle_index_meilisearch_api_error(e, index)
+        handle_meilisearch_api_error(e, index)
 
 
 @app.command()
@@ -285,11 +265,10 @@ def reset_filterable_attributes(
     index: str = Argument(
         ..., help="The name of the index for which to reset the filterable attributes"
     ),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
-    wait: bool = Option(False, "--wait", "-w", help=WAIT_MESSAGE),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    wait: bool = WAIT_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Reset filterable attributes of an index."""
 
@@ -302,19 +281,19 @@ def reset_filterable_attributes(
                 client_index.get_filterable_attributes,
                 wait,
                 "Reset Filterable Attributes",
+                raw,
             )
     except MeiliSearchApiError as e:
-        handle_index_meilisearch_api_error(e, index)
+        handle_meilisearch_api_error(e, index)
 
 
 @app.command()
 def reset_ranking_rules(
     index: str = Argument(..., help="The name of the index for which to reset the ranking rules"),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
-    wait: bool = Option(False, "--wait", "-w", help=WAIT_MESSAGE),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    wait: bool = WAIT_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Reset ranking rules of an index."""
 
@@ -327,9 +306,10 @@ def reset_ranking_rules(
                 client_index.get_ranking_rules,
                 wait,
                 "Reset Ranking Rules",
+                raw,
             )
     except MeiliSearchApiError as e:
-        handle_index_meilisearch_api_error(e, index)
+        handle_meilisearch_api_error(e, index)
 
 
 @app.command()
@@ -337,11 +317,10 @@ def reset_searchable_attributes(
     index: str = Argument(
         ..., help="The name of the index for which to reset the searchable attributes"
     ),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
-    wait: bool = Option(False, "--wait", "-w", help=WAIT_MESSAGE),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    wait: bool = WAIT_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Reset searchable attributes of an index."""
 
@@ -354,19 +333,19 @@ def reset_searchable_attributes(
                 client_index.get_searchable_attributes,
                 wait,
                 "Reset Searchable Attributes",
+                raw,
             )
     except MeiliSearchApiError as e:
-        handle_index_meilisearch_api_error(e, index)
+        handle_meilisearch_api_error(e, index)
 
 
 @app.command()
 def reset_settings(
     index: str = Argument(..., help="The name of the index for which to reset the settings"),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
-    wait: bool = Option(False, "--wait", "-w", help=WAIT_MESSAGE),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    wait: bool = WAIT_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Reset all settings of an index."""
 
@@ -379,19 +358,19 @@ def reset_settings(
                 client_index.get_settings,
                 wait,
                 "Reset Settings",
+                raw,
             )
     except MeiliSearchApiError as e:
-        handle_index_meilisearch_api_error(e, index)
+        handle_meilisearch_api_error(e, index)
 
 
 @app.command()
 def reset_stop_words(
     index: str = Argument(..., help="The name of the index for which to reset the stop words"),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
-    wait: bool = Option(False, "--wait", "-w", help=WAIT_MESSAGE),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    wait: bool = WAIT_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Reset stop words of an index."""
 
@@ -404,19 +383,19 @@ def reset_stop_words(
                 client_index.get_stop_words,
                 wait,
                 "Reset Stop Words",
+                raw,
             )
     except MeiliSearchApiError as e:
-        handle_index_meilisearch_api_error(e, index)
+        handle_meilisearch_api_error(e, index)
 
 
 @app.command()
 def reset_synonyms(
     index: str = Argument(..., help="The name of the index for which to reset the synonums"),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
-    wait: bool = Option(False, "--wait", "-w", help=WAIT_MESSAGE),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    wait: bool = WAIT_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Reset synonyms of an index."""
 
@@ -429,9 +408,10 @@ def reset_synonyms(
                 client_index.get_synonyms,
                 wait,
                 "Reset Synonyms",
+                raw,
             )
     except MeiliSearchApiError as e:
-        handle_index_meilisearch_api_error(e, index)
+        handle_meilisearch_api_error(e, index)
 
 
 @app.command()
@@ -440,11 +420,10 @@ def update_displayed_attributes(
         ..., help="The name of the index for which to update the diplayed attributes"
     ),
     displayed_attributes: List[str] = Argument(..., help="The displayed attributes for the index"),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
-    wait: bool = Option(False, "--wait", "-w", help=WAIT_MESSAGE),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    wait: bool = WAIT_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Update the displayed attributes of an index."""
 
@@ -456,6 +435,7 @@ def update_displayed_attributes(
             client_index.get_displayed_attributes,
             wait,
             "Update Displayed Attributes",
+            raw,
         )
 
 
@@ -465,11 +445,10 @@ def update_distinct_attribute(
         ..., help="The name of the index for which to update the distinct attribute"
     ),
     distinct_attribute: str = Argument(..., help="The distinct attribute for the index"),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
-    wait: bool = Option(False, "--wait", "-w", help=WAIT_MESSAGE),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    wait: bool = WAIT_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Update the distinct attributes of an index."""
 
@@ -477,53 +456,59 @@ def update_distinct_attribute(
     with console.status("Updating distinct attribute..."):
         process_request(
             client_index,
-            partial(client_index.update_distinct_attribute, distinct_attribute),
+            partial(client_index.update_distinct_attribute, distinct_attribute),  # type: ignore
             client_index.get_distinct_attribute,
             wait,
             "Update Distinct Attribute",
+            raw,
         )
 
 
 @app.command()
 def update(
     index: str = Argument(
-        ..., help="The name of the index for which the settings should be udpated"
-    ),
-    primary_key: Optional[str] = Option(None, help="The primary key of the index"),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
+        ..., help="The name of the index for which the settings should be updated"
     ),
+    primary_key: str = Argument(..., help="The primary key of the index"),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Update an index."""
 
     client = create_client(url, master_key)
     try:
         with console.status("Updating index..."):
-            # Ignore type here because the meiliserach-python has the wrong type expected
-            response = client.index(index).update(primaryKey=primary_key)  # type: ignore
+            update_response = client.index(index).update(primary_key=primary_key)
+            status = client.wait_for_task(update_response["uid"])
+            if status["status"] == "failed":
+                console.print(status)
+                sys.exit(1)
+            response = client.get_index(index).__dict__
 
         index_display = {
-            "uid": response.uid,
-            "primary_key": response.primary_key,
-            "created_at": response.created_at,
-            "updated_at": response.updated_at,
+            "uid": response["uid"],
+            "primary_key": response["primary_key"],
+            "created_at": str(response["created_at"]),
+            "updated_at": str(response["updated_at"]),
         }
 
-        console.print(index_display)
+        if raw:
+            console.print_json(json.dumps(index_display))
+        else:
+            console.print(index_display)
     except MeiliSearchApiError as e:
-        handle_index_meilisearch_api_error(e, index)
+        handle_meilisearch_api_error(e, index)
 
 
 @app.command()
 def update_ranking_rules(
     index: str = Argument(..., help="The name of the index for which to update the ranking rules"),
     ranking_rules: List[str] = Argument(..., help="A list of ranking rules"),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
-    wait: bool = Option(False, "--wait", "-w", help=WAIT_MESSAGE),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    wait: bool = WAIT_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Update the ranking rules of an index."""
 
@@ -535,6 +520,7 @@ def update_ranking_rules(
             client_index.get_ranking_rules,
             wait,
             "Update Ranking Rules",
+            raw,
         )
 
 
@@ -544,11 +530,10 @@ def update_searchable_attributes(
         ..., help="The name of the index for which to update the searchable attributes"
     ),
     searchable_attributes: List[str] = Argument(..., help="A list of searchable attributes"),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
-    wait: bool = Option(False, "--wait", "-w", help=WAIT_MESSAGE),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    wait: bool = WAIT_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Update the searchable attributes of an index."""
 
@@ -560,6 +545,7 @@ def update_searchable_attributes(
             client_index.get_searchable_attributes,
             wait,
             "Update Searchable Attributes",
+            raw,
         )
 
 
@@ -582,11 +568,10 @@ def update_settings(
         None,
         help="Synonyms for the index. This should contain JSON passed as a string",
     ),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
-    wait: bool = Option(False, "--wait", "-w", help=WAIT_MESSAGE),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    wait: bool = WAIT_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Update the settings of an index."""
 
@@ -617,6 +602,7 @@ def update_settings(
                 client_index.get_settings,
                 wait,
                 "Update Settings",
+                raw,
             )
     except json.decoder.JSONDecodeError:
         print_json_parse_error_message(synonyms)
@@ -628,11 +614,10 @@ def update_sortable_attributes(
         ..., help="The name of the index for which to update the sortable attributes"
     ),
     sortable_attributes: List[str] = Argument(..., help="A list of sortable attributes"),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
-    wait: bool = Option(False, "--wait", "-w", help=WAIT_MESSAGE),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    wait: bool = WAIT_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Update the sortable attributes of an index."""
 
@@ -644,6 +629,7 @@ def update_sortable_attributes(
             client_index.get_sortable_attributes,
             wait,
             "Update Searchable Attributes",
+            raw,
         )
 
 
@@ -651,11 +637,10 @@ def update_sortable_attributes(
 def update_stop_words(
     index: str = Argument(..., help="The name of the index for which to update the stop words"),
     stop_words: List[str] = Argument(..., help="A list of stop words"),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
-    wait: bool = Option(False, "--wait", "-w", help=WAIT_MESSAGE),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    wait: bool = WAIT_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Update the stop words of an index."""
 
@@ -667,6 +652,7 @@ def update_stop_words(
             client_index.get_stop_words,
             wait,
             "Update Stop Words",
+            raw,
         )
 
 
@@ -676,11 +662,10 @@ def update_synonyms(
     synonyms: str = Argument(
         ..., help="Synonyms for the index. This should contain JSON passed as a string"
     ),
-    url: Optional[str] = Option(None, envvar="MEILI_HTTP_ADDR", help=URL_HELP_MESSAGE),
-    master_key: Optional[str] = Option(
-        None, envvar="MEILI_MASTER_KEY", help=MASTER_KEY_HELP_MESSAGE
-    ),
-    wait: bool = Option(False, "--wait", "-w", help=WAIT_MESSAGE),
+    url: Optional[str] = URL_OPTION,
+    master_key: Optional[str] = MASTER_KEY_OPTION,
+    wait: bool = WAIT_OPTION,
+    raw: bool = RAW_OPTION,
 ) -> None:
     """Update the searchable attributes of an index."""
 
@@ -693,6 +678,7 @@ def update_synonyms(
                 client_index.get_synonyms,
                 wait,
                 "Update Synonyms",
+                raw,
             )
     except json.decoder.JSONDecodeError:
         print_json_parse_error_message(synonyms)
